# Mesh

```sh
automesh mesh --help
<!-- cmdrun automesh mesh --help -->
```

```sh
automesh mesh smooth --help
<!-- cmdrun automesh mesh smooth --help -->
```

## Input/Output File Types

```sh
spn -> exo | inp | mesh | vtk
npy -> exo | inp | mesh | vtk
(beta development) tif -> exo | inp | vtk | mesh
```
